ubii.framework.util package
===========================

.. automodule:: ubii.framework.util
    :members: debug

The following names are imported from elsewhere, to combine all "utility" methods in one place.

.. attribute:: accessor

    refer to :obj:`codestare.async_utils.accessor`

.. attribute:: condition_property

    refer to :obj:`codestare.async_utils.condition_property`

.. attribute:: make_async

    refer to :obj:`codestare.async_utils.make_async`

.. attribute:: CoroutineWrapper

    refer to :obj:`codestare.async_utils.CoroutineWrapper`

.. attribute:: TaskNursery

    refer to :obj:`codestare.async_utils.TaskNursery`

.. attribute:: async_exit_on_exc

    refer to :obj:`codestare.async_utils.async_exit_on_exc`

.. attribute:: RegistryMeta

    refer to :obj:`codestare.async_utils.RegistryMeta`

.. attribute:: Registry

    refer to :obj:`codestare.async_utils.Registry`

.. attribute:: similar

    refer to :obj:`ubii.framework.util.functools.similar`

.. attribute:: hook

    refer to :obj:`ubii.framework.util.functools.hook`

.. attribute:: registry

    refer to :obj:`ubii.framework.util.functools.registry`

.. attribute:: exc_handler_decorator

    refer to :obj:`ubii.framework.util.functools.exc_handler_decorator`

.. attribute:: log_call

    refer to :obj:`ubii.framework.util.functools.log_call`

.. attribute:: ProtoRegistry

    refer to :obj:`ubii.framework.util.functools.ProtoRegistry`

.. attribute:: function_chain

    refer to :obj:`ubii.framework.util.functools.function_chain`

.. attribute:: compose

    refer to :obj:`ubii.framework.util.functools.compose`

.. attribute:: awaitable_predicate

    refer to :obj:`ubii.framework.util.functools.awaitble_predicate`

.. attribute:: make_dict

    refer to :obj:`ubii.framework.util.functools.make_dict`

.. attribute:: merge_dicts

    refer to :obj:`ubii.framework.util.functools.merge_dicts`

.. attribute:: async_compose

    refer to :obj:`ubii.framework.util.functools.async_compose`

.. attribute:: enrich

    refer to :obj:`ubii.framework.util.functools.enrich`

.. attribute:: calc_delta

    refer to :obj:`ubii.framework.util.functools.calc_delta`

.. attribute:: document_decorator

    refer to :obj:`ubii.framework.util.functools.document_decorator`

.. attribute:: dunder

    refer to :obj:`ubii.framework.util.functools.dunder`

Submodules
----------

.. toctree::
   :maxdepth: 4

   ubii.framework.util.collections
   ubii.framework.util.enum
   ubii.framework.util.functools
   ubii.framework.util.typing
